Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(547)

Unified Diff: net/base/origin_bound_cert_store.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: explanitory comment Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/origin_bound_cert_store.h
diff --git a/net/base/origin_bound_cert_store.h b/net/base/origin_bound_cert_store.h
index 1101a0193b9ad56a4d00ea31b256dfb623cbf61b..bd25cde8804e6fa9127dc51a2f641379c1c9377f 100644
--- a/net/base/origin_bound_cert_store.h
+++ b/net/base/origin_bound_cert_store.h
@@ -15,21 +15,24 @@
namespace net {
// An interface for storing and retrieving origin bound certs. Origin bound
// certificates are specified in
// http://balfanz.github.com/tls-obc-spec/draft-balfanz-tls-obc-00.html.
wtc 2012/03/08 02:13:45 Typo: are specification is remove "are", or say "
mattm 2012/03/15 01:48:44 Done.
+// http://balfanz.github.com/tls-obc-spec/draft-balfanz-tls-obc-01.html.
// Owned only by a single OriginBoundCertService object, which is responsible
// for deleting it.
+// Note: For historical reasons, this class is called OriginBoundCertStore, but
+// it's really a DomainBoundCertStore.
class NET_EXPORT OriginBoundCertStore {
public:
// The OriginBoundCert class contains a private key in addition to the origin
// cert, and cert type.
class NET_EXPORT OriginBoundCert {
public:
OriginBoundCert();
- OriginBoundCert(const std::string& origin,
+ OriginBoundCert(const std::string& domain,
SSLClientCertType type,
base::Time creation_time,
base::Time expiration_time,
@@ -37,8 +40,8 @@ class NET_EXPORT OriginBoundCertStore {
const std::string& cert);
~OriginBoundCert();
- // Origin, for instance "https://www.verisign.com:443"
- const std::string& origin() const { return origin_; }
+ // Domain, for instance "verisign.com"
+ const std::string& domain() const { return domain_; }
// TLS ClientCertificateType.
SSLClientCertType type() const { return type_; }
// The time the certificate was created, also the start of the certificate
@@ -54,7 +57,7 @@ class NET_EXPORT OriginBoundCertStore {
const std::string& cert() const { return cert_; }
private:
- std::string origin_;
+ std::string domain_;
SSLClientCertType type_;
base::Time creation_time_;
base::Time expiration_time_;
@@ -71,39 +74,39 @@ class NET_EXPORT OriginBoundCertStore {
// |type| is the ClientCertificateType of the returned certificate,
// |creation_time| stores the start of the validity period of the certificate
// and |expiration_time| is the expiration time of the certificate.
// Returns false if no origin bound cert exists for the specified origin.
virtual bool GetOriginBoundCert(
- const std::string& origin,
+ const std::string& domain,
SSLClientCertType* type,
base::Time* creation_time,
base::Time* expiration_time,
std::string* private_key_result,
std::string* cert_result) = 0;
// Adds an origin bound cert and the corresponding private key to the store.
virtual void SetOriginBoundCert(
- const std::string& origin,
+ const std::string& domain,
SSLClientCertType type,
base::Time creation_time,
base::Time expiration_time,
const std::string& private_key,
const std::string& cert) = 0;
// Removes an origin bound cert and the corresponding private key from the
// store.
- virtual void DeleteOriginBoundCert(const std::string& origin) = 0;
+ virtual void DeleteOriginBoundCert(const std::string& domain) = 0;
- // Deletes all of the origin bound certs that have a creation_date greater
+ // Deletes all of the domain bound certs that have a creation_date greater
// than or equal to |delete_begin| and less than |delete_end|. If a
// base::Time value is_null, that side of the comparison is unbounded.
virtual void DeleteAllCreatedBetween(base::Time delete_begin,
base::Time delete_end) = 0;
// Removes all origin bound certs and the corresponding private keys from
// the store.
virtual void DeleteAll() = 0;
// Returns all origin bound certs and the corresponding private keys.
virtual void GetAllOriginBoundCerts(
std::vector<OriginBoundCert>* origin_bound_certs) = 0;
@@ -15,21 +15,24 @@
namespace net {
-// An interface for storing and retrieving origin bound certs. Origin bound
-// certificates are specified in
-// http://balfanz.github.com/tls-obc-spec/draft-balfanz-tls-obc-00.html.
+// An interface for storing and retrieving domain bound certs.
+// There isn't a domain bound certs spec yet, but the old origin bound
+// certificates are specification is
wtc 2012/03/08 02:13:45 Typo: are specification is remove "are", or say "
mattm 2012/03/15 01:48:44 Done.
@@ -15,21 +15,24 @@
class NET_EXPORT OriginBoundCertStore {
public:
- // The OriginBoundCert class contains a private key in addition to the origin
+ // The OriginBoundCert class contains a private key in addition to the domain
// cert, and cert type.
class NET_EXPORT OriginBoundCert {
@@ -71,39 +74,39 @@ class NET_EXPORT OriginBoundCertStore {
// |creation_time| stores the start of the validity period of the certificate
// and |expiration_time| is the expiration time of the certificate.
- // Returns false if no origin bound cert exists for the specified origin.
+ // Returns false if no domain bound cert exists for the specified domain.
virtual bool GetOriginBoundCert(
@@ -71,39 +74,39 @@ class NET_EXPORT OriginBoundCertStore {
std::string* private_key_result,
std::string* cert_result) = 0;
- // Adds an origin bound cert and the corresponding private key to the store.
+ // Adds a domain bound cert and the corresponding private key to the store.
virtual void SetOriginBoundCert(
@@ -71,39 +74,39 @@ class NET_EXPORT OriginBoundCertStore {
const std::string& private_key,
const std::string& cert) = 0;
- // Removes an origin bound cert and the corresponding private key from the
+ // Removes an domain bound cert and the corresponding private key from the
// store.
@@ -71,39 +74,39 @@ class NET_EXPORT OriginBoundCertStore {
virtual void DeleteAllCreatedBetween(base::Time delete_begin,
base::Time delete_end) = 0;
- // Removes all origin bound certs and the corresponding private keys from
+ // Removes all domain bound certs and the corresponding private keys from
// the store.
virtual void DeleteAll() = 0;
@@ -71,39 +74,39 @@ class NET_EXPORT OriginBoundCertStore {
// the store.
virtual void DeleteAll() = 0;
- // Returns all origin bound certs and the corresponding private keys.
+ // Returns all domain bound certs and the corresponding private keys.
virtual void GetAllOriginBoundCerts(
std::vector<OriginBoundCert>* origin_bound_certs) = 0;

Powered by Google App Engine
This is Rietveld 408576698